pub struct AddHwResult {
pub nodes_moved: Vec<String>,
pub target_nodes: Vec<String>,
pub parent_nodes: Vec<String>,
}Expand description
Result of an add hw-component operation.
Fields
nodes_moved: Vec<String>Xnames moved from the parent group into the target group as part of this operation.
target_nodes: Vec<String>Final membership of the target group after the move.
parent_nodes: Vec<String>Final membership of the parent group after the move.