pub struct DeleteHwResult {
pub nodes_moved: Vec<String>,
pub target_nodes: Vec<String>,
pub parent_nodes: Vec<String>,
}Expand description
Result of a delete hw-component operation.
Fields
nodes_moved: Vec<String>Xnames moved out of the target group and returned to the parent group as part of this operation.
target_nodes: Vec<String>Final membership of the target group after the move.
parent_nodes: Vec<String>Final membership of the parent group after the move.